@@ -1,6 +1,8 @@
-from general_superstaq._init_vars import API_URL, API_VERSION
+from general_superstaq import models
+from general_superstaq._init_vars import API_URL, API_URL_V3, API_VERSION
 from general_superstaq._version import __version__
 from general_superstaq.resource_estimate import ResourceEstimate
+from general_superstaq.service import Service
 from general_superstaq.superstaq_exceptions import (
     SuperstaqException,
     SuperstaqServerException,
@@ -12,19 +14,22 @@ from general_superstaq.typing import Target
 from . import serialization, service, superstaq_client, superstaq_exceptions, typing, validation
 
 __all__ = [
-    "__version__",
     "API_URL",
+    "API_URL_V3",
     "API_VERSION",
     "ResourceEstimate",
+    "Service",
     "SuperstaqException",
-    "SuperstaqUnsuccessfulJobException",
     "SuperstaqServerException",
+    "SuperstaqUnsuccessfulJobException",
     "SuperstaqWarning",
+    "Target",
+    "__version__",
+    "models",
     "serialization",
     "service",
     "superstaq_client",
     "superstaq_exceptions",
     "typing",
-    "Target",
     "validation",
 ]
