@@ -6,9 +6,15 @@ from collections.abc import Mapping, Sequence
 from typing import Any, TypeVar, overload
 
 import general_superstaq as gss
+from general_superstaq.superstaq_client import _SuperstaqClient, _SuperstaqClientV3
 
 TQuboKey = TypeVar("TQuboKey")
 
+CLIENT_VERSION = {
+    "v0.2.0": _SuperstaqClient,
+    "v0.3.0": _SuperstaqClientV3,
+}
+
 
 class Service:
     """This class contains all the services that are used to operate Superstaq."""
@@ -24,10 +30,17 @@ class Service:
         """Initializes the `Service` class.
 
         Args:
-            client: The Superstaq client to use.
+            api_key: The key used for authenticating against the Superstaq API.
+            remote_host: The url of the server exposing the Superstaq API. This will strip anything
+                besides the base scheme and netloc, i.e. it only takes the part of the host of
+                the form `http://example.com` of `http://example.com/test`.
+            api_version: Which version of the API to use. Defaults to `client_superstaq.API_VERSION`
+                (which is the most recent version when this client was downloaded).
+            max_retry_seconds: The time to continue retriable responses. Defaults to 3600.
+            verbose: Whether to print to stderr and stdio any retriable errors that are encountered.
         """
-
-        self._client = gss.superstaq_client._SuperstaqClient(
+        client_version = CLIENT_VERSION[api_version]
+        self._client = client_version(
             client_name="general-superstaq",
             remote_host=remote_host,
             api_key=api_key,
@@ -47,7 +60,6 @@ class Service:
             ($-prefix, commas on LHS every three digits, and two digits after period).
             Otherwise, simply returns a float of the balance.
         """
-
         balance = self._client.get_balance()["balance"]
         if pretty_output:
             return f"{balance:,.2f} credits"
@@ -89,7 +101,7 @@ class Service:
             balance: The new balance.
 
         Raises:
-            SuperstaqException: If requested balance exceeds the limit.
+            superstaq.SuperstaqException: If requested balance exceeds the limit.
 
         Returns:
             String containing status of update (whether or not it failed).
@@ -131,6 +143,7 @@ class Service:
         supports_compile: bool | None = None,
         available: bool | None = None,
         retired: bool | None = None,
+        accessible: bool | None = None,
         **kwargs: bool,
     ) -> list[gss.Target]:
         """Gets a list of Superstaq targets along with their status information.
@@ -146,6 +159,8 @@ class Service:
             available: Optional boolean flag to only return targets that are (not) available
                 to use.
             retired: Optional boolean flag to only return targets that are or are not retired.
+            accessible: Optional boolean flag to only return targets that are (not) accessible
+                to the user.
             kwargs: Any additional, supported flags to restrict/filter returned targets.
 
         Returns:
@@ -158,10 +173,20 @@ class Service:
             supports_compile=supports_compile,
             available=available,
             retired=retired,
+            accessible=accessible,
             **kwargs,
         )
         return self._client.get_targets(**filters)
 
+    def get_my_targets(self) -> list[gss.Target]:
+        """Gets a list of Superstaq targets that the user can submit to and are available along
+        with their status information.
+
+        Returns:
+            A list of Superstaq targets that the user can currently submit to.
+        """
+        return self._client.get_my_targets()
+
     @overload
     def get_user_info(self) -> dict[str, str | float]: ...
 
@@ -171,11 +196,29 @@ class Service:
     @overload
     def get_user_info(self, *, email: str) -> list[dict[str, str | float]]: ...
 
+    @overload
+    def get_user_info(self, *, user_id: int) -> list[dict[str, str | float]]: ...
+
+    @overload
+    def get_user_info(self, *, name: str, user_id: int) -> list[dict[str, str | float]]: ...
+
+    @overload
+    def get_user_info(self, *, email: str, user_id: int) -> list[dict[str, str | float]]: ...
+
     @overload
     def get_user_info(self, *, name: str, email: str) -> list[dict[str, str | float]]: ...
 
+    @overload
     def get_user_info(
-        self, *, name: str | None = None, email: str | None = None
+        self, *, name: str, email: str, user_id: int
+    ) -> list[dict[str, str | float]]: ...
+
+    def get_user_info(
+        self,
+        *,
+        name: str | None = None,
+        email: str | None = None,
+        user_id: int | None = None,
     ) -> dict[str, str | float] | list[dict[str, str | float]]:
         """Gets a dictionary of the user's info.
 
@@ -186,16 +229,17 @@ class Service:
 
         Args:
             name: A name to search by. Defaults to None.
-            email: An email address to search by. Defaults to None
+            email: An email address to search by. Defaults to None.
+            user_id: A user ID to search by. Defaults to None.
 
         Returns:
             A dictionary of the user information. In the case that either the name or email
             query kwarg is used, a list of dictionaries is returned, corresponding to the user
             information for each user that matches the query.
         """
-        user_info = self._client.get_user_info(name=name, email=email)
+        user_info = self._client.get_user_info(name=name, email=email, user_id=user_id)
 
-        if name is None and email is None:
+        if name is None and email is None and user_id is None:
             # If no query then return the only element in the list.
             return user_info[0]
 
@@ -206,8 +250,14 @@ class Service:
         qubo: Mapping[tuple[TQuboKey, ...], float],
         target: str = "ss_unconstrained_simulator",
         repetitions: int = 10,
-        method: str | None = None,
+        method: str = "sim_anneal",
         max_solutions: int = 1000,
+        *,
+        qaoa_depth: int = 1,
+        rqaoa_cutoff: int = 0,
+        dry_run: bool = False,
+        random_seed: int | None = None,
+        **kwargs: object,
     ) -> list[dict[TQuboKey, int]]:
         """Solves a submitted QUBO problem via annealing.
 
@@ -222,15 +272,33 @@ class Service:
                 would be {('a',): 2, ('a', 'b'): 1, ('b', 'c'): -5, (): -3}.
             target: The target to submit the QUBO.
             repetitions: Number of times that the execution is repeated before stopping.
-            method: The parameter specifying method of QUBO solving execution. Currently,
-                will either be the "dry-run" option which runs on dwave's simulated annealer,
-                or defaults to `None` and sends it directly to the specified target.
+            method: The parameter specifying method of QUBO solving execution. Currently, the
+                supported methods include "bruteforce", "sim_anneal", "qaoa", or "rqaoa".
+                Defaults to "sim_anneal" which runs on DWave's simulated annealer.
             max_solutions: A parameter that specifies the max number of output solutions.
+            qaoa_depth: The number of QAOA layers to use. Defaults to 1.
+            rqaoa_cutoff: The stopping point for RQAOA before using switching to a classical
+                solver. Defaults to 0.
+            dry_run: If `method="qaoa"`, a boolean flag to (not) run an ideal 'dry-run'
+                QAOA execution on `target`.
+            random_seed: Optional random seed choice for RQAOA.
+            kwargs: Any optional keyword arguments supported by the qubo solver methods.
 
         Returns:
             A dictionary containing the output solutions.
         """
-        result_dict = self._client.submit_qubo(qubo, target, repetitions, method, max_solutions)
+        result_dict = self._client.submit_qubo(
+            qubo,
+            target,
+            repetitions,
+            method,
+            max_solutions,
+            qaoa_depth=qaoa_depth,
+            rqaoa_cutoff=rqaoa_cutoff,
+            dry_run=dry_run,
+            random_seed=random_seed,
+            **kwargs,
+        )
         return gss.serialization.deserialize(result_dict["solution"])
 
     @staticmethod
@@ -245,7 +313,7 @@ class Service:
         config = getattr(config, "_config_raw", config)  # required to serialize qtrl Managers
         if isinstance(config, dict):
             try:
-                import yaml
+                import yaml  # noqa: PLC0415
 
                 return yaml.safe_dump(config)
 
@@ -312,7 +380,6 @@ class Service:
             ValueError: If either file path already exists and overwrite is not True.
             ModuleNotFoundError: If file paths are unspecified and PyYAML cannot be imported.
         """
-
         if pulses_file_path and variables_file_path:
             pulses_file_exists = os.path.exists(pulses_file_path)
             variables_file_exists = os.path.exists(variables_file_path)
@@ -336,11 +403,11 @@ class Service:
             config_dict = self.aqt_get_configs()
             with open(pulses_file_path, "w") as text_file:
                 text_file.write(config_dict["pulses"])
-                print(f"Pulses configuration saved to {pulses_file_path}.")
+                print(f"Pulses configuration saved to {pulses_file_path}.")  # noqa: T201
 
             with open(variables_file_path, "w") as text_file:
                 text_file.write(config_dict["variables"])
-                print(f"Variables configuration saved to {variables_file_path}.")
+                print(f"Variables configuration saved to {variables_file_path}.")  # noqa: T201
 
             return None
 
@@ -349,7 +416,7 @@ class Service:
 
         else:
             try:
-                import yaml
+                import yaml  # noqa: PLC0415
             except ImportError:
                 raise ModuleNotFoundError(
                     "The PyYAML package is required to parse AQT configuration files. "
@@ -418,7 +485,7 @@ class Service:
 
         Raises:
             ValueError: If the target or noise model are not valid.
-            SuperstaqServerException: If the request fails.
+            ~gss.SuperstaqServerException: If the request fails.
         """
         noise_dict: dict[str, object] = {}
         if noise:
